@@ -32,28 +32,36 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
         // let re_key3 = Regex::new(format!("(?i):{},", key).as_str()).unwrap();
 
         if let Value::String(m) = &value {
-            sql = sql.replace(&format!(":{}", key), &format!("'{}'", m));
-            sql = sql.replace(&format!("#{}#", key), &format!("'{}'", m));
+
+            let n = m.replace("'", "''");
+            sql = sql.replace(&format!(":{}", key), &format!("'{}'", n));
+            sql = sql.replace(&format!("#{}#", key), &format!("'{}'", n));
 
             // sql = re_key.replace_all(&sql, format!("'{}'\n", m.replace("'","''")).as_str()).to_string();
             // sql = re_key2.replace_all(&sql, format!("'{}')", m.replace("'","''")).as_str()).to_string();
             // sql = re_key3.replace_all(&sql, format!("'{}',", m.replace("'","''")).as_str()).to_string();
         }
         if let Value::StringLikeLeft(m) = &value {
-            sql = sql.replace(&format!(":{}", key), &format!("'%{}'", m));
-            sql = sql.replace(&format!("#{}#", key), &format!("'%{}'", m));
+
+            let n = m.replace("'", "''");
+            sql = sql.replace(&format!(":{}", key), &format!("'%{}'", n));
+            sql = sql.replace(&format!("#{}#", key), &format!("'%{}'", n));
 
             // sql = re_key.replace_all(&sql, format!("'%{}'\n", m).as_str()).to_string();
         }
         if let Value::StringLikeRight(m) = &value {
-            sql = sql.replace(&format!(":{}", key), &format!("'{}%'", m));
-            sql = sql.replace(&format!("#{}#", key), &format!("'{}%'", m));
+
+            let n = m.replace("'", "''");
+            sql = sql.replace(&format!(":{}", key), &format!("'{}%'", n));
+            sql = sql.replace(&format!("#{}#", key), &format!("'{}%'", n));
 
             // sql = re_key.replace_all(&sql, format!("'{}%'\n", m).as_str()).to_string();
         }
         if let Value::StringLikeBoth(m) = &value {
-            sql = sql.replace(&format!(":{}", key), &format!("'%{}%'", m));
-            sql = sql.replace(&format!("#{}#", key), &format!("'%{}%'", m));
+
+            let n = m.replace("'", "''");
+            sql = sql.replace(&format!(":{}", key), &format!("'%{}%'", n));
+            sql = sql.replace(&format!("#{}#", key), &format!("'%{}%'", n));
 
             // sql = re_key.replace_all(&sql, format!("'%{}%'\n", m).as_str()).to_string();
         }
@@ -97,8 +105,11 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
                 if i > 0 {
                     m.push_str(", ");
                 }
-                m.push_str(format!("'{}'", item).as_str());
+
+                let n = item.replace("'", "''");
+                m.push_str(format!("'{}'", n).as_str());
             }
+
             sql = sql.replace(&format!(":{}", key), &format!("{}", m));
             sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
 
@@ -124,11 +135,11 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
             // sql = re_key3.replace_all(&sql, format!("{},", m).as_str()).to_string();
         }
     }
-    sql = sql.replace("'", "''");
+    // sql = sql.replace("'", "''");
     sql
 }
 #[deprecated(
-since = "0.5.0",
+since = "0.5.01",
 note = "Please use the bind_variables instead"
 )]
 pub fn bind_values(value_map : &HashMap<String, Value>) -> String {
